@@ -1,4 +1,8 @@
-#!/usr/bin/perl
+package Mail::DKIM::SignerPolicy;
+use strict;
+use warnings;
+our $VERSION = '1.20200907'; # VERSION
+# ABSTRACT: determines signing parameters for a message
 
 # Copyright 2005-2006 Messiah College. All rights reserved.
 # This program is free software; you can redistribute it and/or
@@ -6,27 +10,31 @@
 #
 # Written by Jason Long <jlong@messiah.edu>
 
-use strict;
-use warnings;
-
-package Mail::DKIM::SignerPolicy;
-
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Mail::DKIM::SignerPolicy - determines signing parameters for a message
 
+=head1 VERSION
+
+version 1.20200907
+
 =head1 DESCRIPTION
 
-Objects of type Mail::DKIM::SignerPolicy are used by Mail::DKIM::Signer.
-To take advantage of policy objects, create your own Perl class that
-extends this class. The only method you need to provide is the apply()
-method.
+A "signer policy" is an object, class, or function used by
+L<Mail::DKIM::Signer> to determine what signatures to add to the
+current message. To take advantage of signer policies, create your
+own Perl class that extends the L<Mail::DKIM::SignerPolicy> class.
+The only method you need to implement is the apply() method.
 
-The apply() method takes as a parameter the Mail::DKIM::Signer object.
+The apply() method takes as a parameter the L<Mail::DKIM::Signer> object.
 Using this object, it can determine some properties of the message (e.g.
 what the From: address or Sender: address is). Then it sets various
 signer properties as desired. The apply() method should
@@ -36,17 +44,18 @@ is returned, then the message is "skipped" (i.e. not signed).
 Here is an example of a policy that always returns the same values:
 
   package MySignerPolicy;
-  use base "Mail::DKIM::SignerPolicy";
+  use base 'Mail::DKIM::SignerPolicy';
 
   sub apply
   {
       my $self = shift;
       my $signer = shift;
   
-      $signer->algorithm("rsa-sha1");
-      $signer->method("relaxed");
-      $signer->domain("example.org");
-      $signer->selector("selector1");
+      $signer->algorithm('rsa-sha1');
+      $signer->method('relaxed');
+      $signer->domain('example.org');
+      $signer->selector('selector1');
+      $signer->key_file('private.key');
   
       return 1;
   }
@@ -54,9 +63,8 @@ Here is an example of a policy that always returns the same values:
 To use this policy, simply specify the name of the class as the Policy
 parameter...
 
-  my $dkim = Mail::DKIM::Signer->new_object(
-                  Policy => "MySignerPolicy",
-                  KeyFile => "private.key"
+  my $dkim = Mail::DKIM::Signer->new(
+                  Policy => 'MySignerPolicy',
              );
 
 =head1 ADVANCED
@@ -85,13 +93,50 @@ Again, if you do not want any signatures, return zero or undef. If you
 use add_signature() to create a signature, the default signature will
 not be created, even if you return nonzero.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Jason Long, E<lt>jlong@messiah.eduE<gt>
+=over 4
+
+=item *
+
+Jason Long <jason@long.name>
+
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=item *
+
+Bron Gondwana <brong@fastmailteam.com> (ARC)
+
+=back
+
+=head1 THANKS
+
+Work on ensuring that this module passes the ARC test suite was
+generously sponsored by Valimail (https://www.valimail.com/)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2007 by Messiah College
+=over 4
+
+=item *
+
+Copyright (C) 2013 by Messiah College
+
+=item *
+
+Copyright (C) 2010 by Jason Long
+
+=item *
+
+Copyright (C) 2017 by Standcore LLC
+
+=item *
+
+Copyright (C) 2020 by FastMail Pty Ltd
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
